DioFileUploader class

Wrapper to upload file using Dio client

Constructors

DioFileUploader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getFileContentType(String fileExtension) String
getFileExtension(String? filePath) String?
uploadFileFromURL({required Map<String, dynamic> metaData, required String uploadUrl, required String filePath, required String contentType, String? successMessage, String? errorMessage}) EitherResponse<String>
Uploads file to the server